# BinodTharu
Your package of happiness

![](https://alltimetrends.com/wp-content/uploads/2020/08/image-26-e1596777470888-800x277.png)
# `pip install binodtharu`

### By [Sayantan Das](https://www.linkedin.com/in/ucalyptus)
